# gpnlake

Единая библиотека для упрощённого взаимодействия с озером данных (как с файловым хранилищем, так и сКЛАД).

**Ключевые возможности:**

- **GreenPlumClient**: позволяет считывать и записывать данные из Greenplum/Postgre БД.
- **ClickHouseClient**: позволяет считывать высокодискретные данные из ClickHouse БД.
- **DFSClient**: надёжная загрузка и скачивание файлов в файловое хранилище DFS с автоматическим созданием директорий.

